pub struct Error {
pub message: String,
pub source: Option<Arc<dyn Any + Send + Sync>>,
pub extensions: Option<ErrorExtensionValues>,
}Expand description
An error with a message and optional extensions.
Fields
message: StringThe error message.
source: Option<Arc<dyn Any + Send + Sync>>The source of the error.
extensions: Option<ErrorExtensionValues>Extensions to the error.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn new_with_source(source: impl Display + Send + Sync + 'static) -> Error
pub fn new_with_source(source: impl Display + Send + Sync + 'static) -> Error
Create an error with a type that implements Display, and it will also
set the source of the error to this value.
Sourcepub fn into_server_error(self, pos: Pos) -> ServerError
pub fn into_server_error(self, pos: Pos) -> ServerError
Convert the error to a server error.